#
# Copyright (c) 2004 Nokia
# Author: Timo Savola <tsavola@movial.fi>
#
# Licensed under GPL, see COPYING for details.
#

import sys, os, socket
from os.path import join, exists
from sb import config

##
## Create config file

def configure(target = None, host = None, nfs_host = None):
	if not target:
		target = config.current()

	if not host:
		raise RuntimeError("Host not specified")

	if not nfs_host:
		nfs_host = socket.gethostbyname_ex(socket.gethostname())[0]

	user = os.getenv("USER")

	out = file(config.join_sandbox("/targets/%s.sbrsh" % target), "w")
	out.write("%s\t%s\n" % (target, host))

	out.write("\tnfs  %s:/scratchbox/users/%s/targets/%s / rw,nolock,noac\n" % (nfs_host, user, target))
	out.write("\tnfs  %s:/scratchbox/users/%s/home /home rw,nolock,noac\n" % (nfs_host, user))
	out.write("\tbind /tmp     /tmp\n")
	out.write("\tbind /proc    /proc\n")
	out.write("\tbind /dev     /dev\n")
	out.write("\tbind /dev/pts /dev/pts\n")

##
## Add access rights for user

def add(host, account = None):
	if not account:
		account = socket.gethostbyname(socket.gethostname())

	if account.find("@") < 0:
		user = os.getenv("USER")
		account = "%s@%s" % (user, account)

	args = ["ssh", "-l", "root", host, "/usr/sbin/sbrshd", "add", account]
	return os.spawnvp(os.P_WAIT, args[0], args)

##
## Mount, Unmount

def mount(target = None, verbose = True):
	if verbose:
		msg = "Mounting"
	else:
		msg = None

	run_sbrsh(target, "--mount", msg)

def umount(target = None, verbose = True):
	if verbose:
		msg = "Unmounting"
	else:
		msg = None

	run_sbrsh(target, "--umount", msg)

def run_sbrsh(target, mode, msg):
	if not target:
		target = config.current()

	conf = config.join_sandbox("/targets/%s.sbrsh" % target)
	if not exists(conf):
		conf = config.join_sandbox("/home/%s/.sbrsh" % os.getenv("USER"))
		if not exists(conf):
			return

	found = False
	for line in file(conf).readlines():
		parts = line.split(None)
		if not line[0].isspace() and parts and parts[0] == target:
			found = True

	if not found:
		return

	if msg:
		print msg, target, "..."

	args = [join(config.tools_dir, "sbrsh"), "-t", target, "-c", conf, mode]
	retval = os.spawnv(os.P_WAIT, args[0], args)

	if retval and msg:
		print "Failed!"

	return retval

